@@ -39,7 +39,7 @@ from options import (
     version,
 )
 
-from utils.utils import humanize_file_size, shorten_path
+from utils.utils import humanize_file_size, shorten_path, format_relative_time
 from workers import WorkerThread, MaintenanceWorker, TaskList, workers
 from gui_settings_window import gui_settings_window
 
@@ -74,7 +74,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         super(MainWindow, self).__init__()
         self.setupUi(self)
         self.setWindowTitle(f"OneDriveGUI v{version}")
-        self.setWindowIcon(QIcon(DIR_PATH + "/resources/images/icons8-clouds-80-dark-edge.png"))
+        self.setWindowIcon(QIcon(DIR_PATH + "/resources/images/icons8-cloud-80.png"))
 
         if gui_settings.get("frameless_window") == "True":
             self.setWindowFlags(Qt.FramelessWindowHint)
@@ -131,6 +131,11 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             self.profile_status_pages[profile].quit_gui_signal.connect(self.graceful_shutdown)
             self.stackedLayout.addWidget(self.profile_status_pages[profile])
 
+            # Connect scroll events for timestamp updates
+            listWidget = self.profile_status_pages[profile].listWidget
+            scrollbar = listWidget.verticalScrollBar()
+            scrollbar.valueChanged.connect(self.on_list_scrolled)
+
         self.verticalLayout_2.addLayout(self.stackedLayout)
 
         # Ensure all profiles in comboBox are aligned to center
@@ -150,7 +155,8 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         # System Tray
         self.tray = QSystemTrayIcon()
         if self.tray.isSystemTrayAvailable():
-            icon = QIcon(DIR_PATH + "/resources/images/icons8-clouds-80-dark-edge.png")
+            # Initial icon will be updated by update_tray_icon() after profiles are loaded
+            icon = QIcon(DIR_PATH + "/resources/images/icons8-cloud-80.png")
             menu = QMenu()
 
             show_action = menu.addAction("Show/Hide")
@@ -165,11 +171,23 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             self.tray.setIcon(icon)
             self.tray.setContextMenu(menu)
             self.tray.show()
+            # Initial tooltip - will be updated by update_tray_icon()
             self.tray.setToolTip("OneDriveGUI")
 
         else:
             self.tray = None
 
+        # Version check results storage
+        self.client_version_status = {
+            "label_text": "",
+            "tooltip_text": "",
+            "min_requirements_met": True,
+        }
+        self.gui_version_status = {
+            "label_text": "",
+            "tooltip_text": "",
+        }
+
         self.refresh_process_status = QTimer()
         self.refresh_process_status.setSingleShot(False)
         self.refresh_process_status.timeout.connect(self.onedrive_process_status)
@@ -180,11 +198,28 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         self.check_client_version.timeout.connect(self.client_version_check)
         self.check_client_version.start(500)
 
+        self.check_gui_version = QTimer()
+        self.check_gui_version.setSingleShot(True)
+        self.check_gui_version.timeout.connect(self.gui_version_check)
+        self.check_gui_version.start(1000)
+
         self.auto_sync = QTimer()
         self.auto_sync.setSingleShot(True)
         self.auto_sync.timeout.connect(self.autostart_monitor)
         self.auto_sync.start(1000)
 
+        # Timer to refresh relative times for completed transfers
+        self.refresh_relative_times = QTimer()
+        self.refresh_relative_times.setSingleShot(False)
+        self.refresh_relative_times.timeout.connect(self.update_relative_times)
+        self.refresh_relative_times.start(60000)  # Update every 60 seconds
+
+        # Debounce timer for scroll-triggered updates
+        self.scroll_update_timer = QTimer()
+        self.scroll_update_timer.setSingleShot(True)
+        self.scroll_update_timer.timeout.connect(self.update_relative_times)
+        self.scroll_update_timer.setInterval(200)  # 200ms debounce delay
+
     def mousePressEvent(self, event):
         if gui_settings.get("frameless_window") == "True":
             self.dragPos = event.globalPosition().toPoint()
@@ -232,7 +267,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             sys.exit()
 
         elif close_question == QMessageBox.No:
-            logging.debug("[GUI] Keeping OneDriveGUI running.")
+            logging.info("[GUI] Keeping OneDriveGUI running.")
 
     def stop_onedrive_monitor(self, profile_name):
         if profile_name in workers:
@@ -248,13 +283,13 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         try:
             if self.tray.isSystemTrayAvailable():
                 self.hide()
-                logging.info("[GUI] Minimizing main window to tray")
+                logging.debug("[GUI] Minimizing main window to tray")
             else:
                 self.setWindowState(Qt.WindowMinimized)
-                logging.info("[GUI] Minimizing main window to taskbar/dock")
+                logging.debug("[GUI] Minimizing main window to taskbar/dock")
         except:
             self.setWindowState(Qt.WindowMinimized)
-            logging.info("[GUI] Minimizing main window to taskbar/dock")
+            logging.debug("[GUI] Minimizing main window to taskbar/dock")
 
     def show_setup_wizard(self):
         setup_wizard.show()
@@ -271,9 +306,8 @@ class MainWindow(QMainWindow, Ui_MainWindow):
     def client_version_check(self):
         """
         Compare installed version of OneDrive client with the latest version on Github releases.
-        Show workings or prevent sync when installed version is too old.
+        Store results and call display_version_warnings() to show combined warnings.
         """
-        pixmap_warning = QPixmap(DIR_PATH + "/resources/images/warning.png").scaled(20, 20, Qt.KeepAspectRatio)
         s = requests.Session()
         version_label_text = ""
         version_tooltip_text = ""
@@ -308,7 +342,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             latest_client_version = get_latest_client_version()
             installed_client_version = get_installed_client_version()
 
-            logging.debug(f"[GUI] Client version check: Installed: {installed_client_version[0]} | Latest: {latest_client_version}")
+            logging.info(f"[GUI] Client version check: Installed: {installed_client_version[0]} | Latest: {latest_client_version}")
 
             if not installed_client_version:
                 version_label_text = "OneDrive client not found!"
@@ -332,28 +366,133 @@ class MainWindow(QMainWindow, Ui_MainWindow):
                 version_label_text = "OneDrive client is out of date!"
                 version_tooltip_text = f"OneDrive client is out of date! \n Installed: {installed_client_version[0]} \n Latest: {latest_client_version}"
 
-            for profile_name in global_config:
-                self.profile_status_pages[profile_name].label_onedrive_status.setOpenExternalLinks(True)
+            # Store results
+            self.client_version_status["label_text"] = version_label_text
+            self.client_version_status["tooltip_text"] = version_tooltip_text
+            self.client_version_status["min_requirements_met"] = min_requirements_met
 
-                if version_label_text:
-                    self.profile_status_pages[profile_name].label_onedrive_status.setText(version_label_text)
-
-                if not min_requirements_met:
-                    # Disable Start Sync button if OneDrive client is too old (smaller then min_supported_version_num).
-                    self.profile_status_pages[profile_name].pushButton_start.setEnabled(False)
-                    self.profile_status_pages[profile_name].pushButton_start_stop.setEnabled(False)
-                    self.profile_status_pages[profile_name].pushButton_profiles.setEnabled(False)
-                    self.profile_status_pages[profile_name].label_version_check.setToolTip(version_tooltip_text)
-                    self.profile_status_pages[profile_name].label_version_check.setPixmap(pixmap_warning)
-
-                elif latest_client_version not in installed_client_version:
-                    # Display warning in GUI when installed OneDrive client is not up to date.
-                    self.profile_status_pages[profile_name].label_version_check.setToolTip(version_tooltip_text)
-                    self.profile_status_pages[profile_name].label_version_check.setPixmap(pixmap_warning)
+            # Display combined warnings
+            self.display_version_warnings()
 
         except Exception as e:
             logging.error(f"Client version check failed: {e}")
 
+    def gui_version_check(self):
+        """
+        Compare installed version of OneDriveGUI with the latest version on Github releases.
+        Store results and call display_version_warnings() to show combined warnings.
+        """
+        s = requests.Session()
+        version_label_text = ""
+        version_tooltip_text = ""
+
+        def parse_semantic_version(version_string):
+            """Parse semantic version string (e.g., 'v1.2.3' or '1.2.3') into tuple (1, 2, 3)"""
+            try:
+                # Remove 'v' prefix if present
+                clean_version = version_string.strip().lstrip("v")
+                # Split by '.' and convert to integers
+                parts = [int(x) for x in clean_version.split(".")]
+                # Ensure we have at least 3 parts (major, minor, patch)
+                while len(parts) < 3:
+                    parts.append(0)
+                return tuple(parts[:3])  # Return only first 3 parts
+            except Exception as e:
+                logging.error(f"Failed to parse version '{version_string}': {e}")
+                return None
+
+        def get_latest_gui_version():
+            """Fetch latest GUI version from GitHub releases"""
+            latest_url = "https://api.github.com/repos/bpozdena/OneDriveGUI/releases/latest"
+            try:
+                response = s.get(latest_url, timeout=1)
+                latest_gui_version = response.json()["tag_name"]
+                return latest_gui_version
+            except Exception as e:
+                logging.error(f"Failed to fetch latest GUI version: {e}")
+                return None
+
+        try:
+            latest_gui_version = get_latest_gui_version()
+            installed_gui_version = version  # From options.py
+
+            if not latest_gui_version:
+                # Network issue or API error - don't show warning
+                logging.warning("[GUI] Unable to check for latest OneDriveGUI version")
+                return
+
+            # Parse versions for comparison
+            installed_version_tuple = parse_semantic_version(installed_gui_version)
+            latest_version_tuple = parse_semantic_version(latest_gui_version)
+
+            if not installed_version_tuple or not latest_version_tuple:
+                logging.error("[GUI] Failed to parse GUI versions for comparison")
+                return
+
+            logging.info(f"[GUI] GUI version check: Installed: v{installed_gui_version} | Latest: {latest_gui_version}")
+
+            # Compare versions
+            if installed_version_tuple < latest_version_tuple:
+                version_label_text = "OneDriveGUI is out of date!"
+                version_tooltip_text = f"OneDriveGUI is out of date! \n Installed: v{installed_gui_version} \n Latest: {latest_gui_version}"
+            else:
+                logging.info("[GUI] OneDriveGUI is up to date")
+
+            # Store results
+            self.gui_version_status["label_text"] = version_label_text
+            self.gui_version_status["tooltip_text"] = version_tooltip_text
+
+            # Display combined warnings
+            self.display_version_warnings()
+
+        except Exception as e:
+            logging.error(f"GUI version check failed: {e}")
+
+    def display_version_warnings(self):
+        """
+        Display combined version warnings for both OneDrive client and GUI.
+        This method combines warnings from both version checks and displays them together.
+        """
+        pixmap_warning = QPixmap(DIR_PATH + "/resources/images/warning.png").scaled(20, 20, Qt.KeepAspectRatio)
+
+        # Combine label texts (use <br> for HTML line break in Qt labels)
+        label_texts = []
+        if self.client_version_status["label_text"]:
+            label_texts.append(self.client_version_status["label_text"])
+        if self.gui_version_status["label_text"]:
+            label_texts.append(self.gui_version_status["label_text"])
+
+        combined_label_text = "<br>".join(label_texts) if label_texts else ""
+
+        # Combine tooltip texts
+        tooltip_parts = []
+        if self.client_version_status["tooltip_text"]:
+            tooltip_parts.append(self.client_version_status["tooltip_text"])
+        if self.gui_version_status["tooltip_text"]:
+            tooltip_parts.append(self.gui_version_status["tooltip_text"])
+
+        combined_tooltip_text = "\n---\n".join(tooltip_parts) if tooltip_parts else ""
+
+        # Display warnings in all profile status pages
+        for profile_name in global_config:
+            page = self.profile_status_pages[profile_name]
+            page.label_onedrive_status.setOpenExternalLinks(True)
+
+            # Set combined label text
+            if combined_label_text:
+                page.label_onedrive_status.setText(combined_label_text)
+
+            # Handle critical client version issues (disable sync)
+            if not self.client_version_status["min_requirements_met"]:
+                page.pushButton_start.setEnabled(False)
+                page.pushButton_start_stop.setEnabled(False)
+                page.pushButton_profiles.setEnabled(False)
+
+            # Set warning icon and tooltip if any warnings exist
+            if combined_tooltip_text:
+                page.label_version_check.setToolTip(combined_tooltip_text)
+                page.label_version_check.setPixmap(pixmap_warning)
+
     def onedrive_process_status(self):
         # Check OneDrive status and start/stop sync button.
         pixmap_running = QPixmap(DIR_PATH + "/resources/images/icons8-green-circle-48.png").scaled(24, 24, Qt.KeepAspectRatio)
@@ -390,21 +529,182 @@ class MainWindow(QMainWindow, Ui_MainWindow):
                     profile_status_page.pushButton_start_stop.clicked.disconnect()
                     profile_status_page.pushButton_start_stop.clicked.connect(profile_status_page.stop_monitor)
 
+        # Update system tray icon based on aggregate status
+        self.update_tray_icon()
+
+    def is_ignorable_error(self, error_text):
+        """
+        Check if an error message should be ignored for tray icon status.
+        Returns True if the error should be ignored.
+        """
+        if not error_text:
+            return True
+
+        # List of error patterns to ignore
+        ignored_patterns = ["inotify_add_watch failed", "The local file system returned an error with the following message"]
+
+        error_lower = error_text.lower()
+        for pattern in ignored_patterns:
+            if pattern.lower() in error_lower:
+                return True
+
+        return False
+
+    def aggregate_tray_status(self):
+        """
+        Aggregate status across all profiles to determine system tray icon state.
+        Returns: tuple (status_state, running_count, total_count, profile_statuses)
+
+        status_state: 'ERROR', 'STOPPED', 'SYNCING', or 'IDLE'
+        Priority: ERROR > STOPPED > SYNCING > IDLE
+        """
+        if not global_config:
+            return ("IDLE", 0, 0, {})
+
+        total_count = len(global_config)
+        running_count = 0
+        profile_statuses = {}
+
+        has_error = False
+        has_stopped = False
+        has_syncing = False
+
+        for profile_name in global_config:
+            # Check if worker is running
+            is_running = profile_name in workers and workers[profile_name].isRunning()
+
+            # Get status message from profile status page
+            if profile_name in self.profile_status_pages:
+                status_msg = self.profile_status_pages[profile_name].label_onedrive_status.text()
+                error_tooltip = self.profile_status_pages[profile_name].label_error_icon.toolTip()
+            else:
+                status_msg = ""
+                error_tooltip = ""
+
+            # Categorize this profile's state
+            if not is_running:
+                profile_state = "STOPPED"
+                has_stopped = True
+            elif (not self.is_ignorable_error(error_tooltip) and not self.is_ignorable_error(status_msg)) and (
+                error_tooltip or "Error:" in status_msg or "error" in status_msg.lower() or "failed" in status_msg.lower() or "crashed" in status_msg.lower()
+            ):
+                profile_state = "ERROR"
+                has_error = True
+                running_count += 1
+            elif "sync in progress" in status_msg.lower() or "processing" in status_msg.lower() or "starting" in status_msg.lower() or "initializing" in status_msg.lower():
+                profile_state = "SYNCING"
+                has_syncing = True
+                running_count += 1
+            elif is_running:
+                profile_state = "IDLE"
+                running_count += 1
+            else:
+                profile_state = "STOPPED"
+                has_stopped = True
+
+            profile_statuses[profile_name] = {"state": profile_state, "status_msg": status_msg if status_msg else "stopped", "is_running": is_running}
+
+        # Determine overall state with priority
+        if has_error:
+            overall_state = "ERROR"
+        elif has_stopped:
+            overall_state = "STOPPED"
+        elif has_syncing:
+            overall_state = "SYNCING"
+        else:
+            overall_state = "IDLE"
+
+        return (overall_state, running_count, total_count, profile_statuses)
+
+    def generate_tray_tooltip(self, overall_state, running_count, total_count, profile_statuses):
+        """
+        Generate detailed tooltip showing status of all profiles.
+        """
+        if not profile_statuses:
+            return "OneDriveGUI - No profiles configured"
+
+        # Summary line
+        if running_count == total_count and overall_state != "ERROR":
+            summary = f"All {total_count} profile(s) running"
+        elif running_count == 0:
+            summary = f"All {total_count} profile(s) stopped"
+        else:
+            summary = f"{running_count} of {total_count} profile(s) running"
+
+        # Add overall state indicator
+        state_indicators = {"ERROR": "Sync error detected", "STOPPED": "Sync stopped", "SYNCING": "Syncing...", "IDLE": "All syncs complete"}
+        summary += f" - {state_indicators.get(overall_state, '')}"
+
+        # Build detailed list
+        lines = [summary, ""]
+        for profile_name, status_info in profile_statuses.items():
+            state = status_info["state"]
+            status_msg = status_info["status_msg"]
+
+            # Add text indicator for each profile
+            if state == "ERROR":
+                indicator = "[ERROR]"
+            elif state == "STOPPED":
+                indicator = "[STOPPED]"
+            elif state == "SYNCING":
+                indicator = "[SYNCING]"
+            else:
+                indicator = "[IDLE]"
+
+            # Shorten status message if too long
+            if len(status_msg) > 50:
+                status_msg = status_msg[:47] + "..."
+
+            lines.append(f"{indicator} {profile_name}: {status_msg}")
+
+        return "\n".join(lines)
+
+    def update_tray_icon(self):
+        """
+        Update system tray icon and tooltip based on current sync status.
+        """
+        if not self.tray:
+            return
+
+        # Get aggregated status
+        overall_state, running_count, total_count, profile_statuses = self.aggregate_tray_status()
+
+        # Select icon based on state
+        icon_map = {
+            "ERROR": DIR_PATH + "/resources/images/icons8-cloud-error-80.png",
+            "STOPPED": DIR_PATH + "/resources/images/icons8-cloud-stop-80.png",
+            "SYNCING": DIR_PATH + "/resources/images/icons8-cloud-sync-80.png",
+            "IDLE": DIR_PATH + "/resources/images/icons8-cloud-done-80.png",
+        }
+
+        icon_path = icon_map.get(overall_state, DIR_PATH + "/resources/images/icons8-cloud-80.png")
+        icon = QIcon(icon_path)
+        tooltip = self.generate_tray_tooltip(overall_state, running_count, total_count, profile_statuses)
+
+        if self.tray.toolTip() != tooltip:
+            logging.debug("Updating tray icon and tooltip")
+            self.tray.setIcon(icon)
+            self.tray.setToolTip(tooltip)
+
     def autostart_monitor(self):
         # Auto-start sync if compatible version of OneDrive client is installed.
         for profile_name in global_config:
-            logging.debug(f"[{profile_name}] Compatible client version found: {self.profile_status_pages[profile_name].pushButton_start.isEnabled()}")
-            logging.debug(f"[{profile_name}] Auto-sync enabled for profile: {global_config[profile_name]['auto_sync']}")
+            logging.info(f"[{profile_name}] Compatible client version found: {self.profile_status_pages[profile_name].pushButton_start.isEnabled()}")
+            logging.info(f"[{profile_name}] Auto-sync enabled for profile: {global_config[profile_name]['auto_sync']}")
 
             if self.profile_status_pages[profile_name].pushButton_start.isEnabled() and global_config[profile_name]["auto_sync"] == "True":
                 self.start_onedrive_monitor(profile_name)
 
     def start_onedrive_monitor(self, profile_name, options=""):
+        # Clear any previous error messages when starting sync
+        self.profile_status_pages[profile_name].label_error_icon.clear()
+        self.profile_status_pages[profile_name].label_error_icon.setToolTip("")
+
         if profile_name not in workers:
             workers[profile_name] = WorkerThread(profile_name, options)
             workers[profile_name].start()
         else:
-            logging.info(f"Worker for profile {profile_name} is already running. Please stop it first.")
+            logging.warning(f"Worker for profile {profile_name} is already running. Please stop it first.")
             logging.info(f"Running workers: {workers}")
 
         if "True" not in gui_settings.get("QWebEngine_login"):
@@ -425,7 +725,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         try:
             workers[profile_name].finished.connect(lambda: self.remove_worker(profile_name))
         except KeyError:
-            logging.debug(f"[GUI] The worker for profile {profile_name} is already stopped.")
+            logging.info(f"[GUI] The worker for profile {profile_name} is already stopped.")
 
     def resync_auth_dialog(self, profile_name):
         resync_question = QMessageBox(
@@ -497,6 +797,17 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         self.profile_status_pages[profile].label_free_space.setText(data["free_space"])
         self.profile_status_pages[profile].label_account_type.setText(data["account_type"])
 
+        # Handle error message display
+        if "error_message" in data and data["error_message"]:
+            # Show error icon with full error message in tooltip
+            pixmap_warning = QPixmap(DIR_PATH + "/resources/images/warning.png").scaled(20, 20, Qt.KeepAspectRatio)
+            self.profile_status_pages[profile].label_error_icon.setPixmap(pixmap_warning)
+            self.profile_status_pages[profile].label_error_icon.setToolTip(data["error_message"])
+        else:
+            # Clear error icon
+            self.profile_status_pages[profile].label_error_icon.clear()
+            self.profile_status_pages[profile].label_error_icon.setToolTip("")
+
     def event_update_progress(self, data, profile):
         """
         data:
@@ -509,7 +820,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         """
         _sync_dir = os.path.expanduser(global_config[profile]["onedrive"]["sync_dir"].strip('"'))
 
-        logging.info(data)
+        logging.debug(data)
         file_path = f"{_sync_dir}" + "/" + data["file_path"]
         absolute_path = QFileInfo(file_path).absolutePath().replace(" ", "%20")
         relative_path_display = os.path.relpath(QFileInfo(file_path).absolutePath(), _sync_dir + os.path.sep)
@@ -536,7 +847,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
                 if file_name == item_file_name and item_incomplete:
                     # If current file is already in the list and progress bar is not complete, update the existing item.
                     # Otherwise skip and create a new item.
-                    logging.info("Updating list item")
+                    logging.debug("Updating list item")
 
                     item_widget.set_progress(int(progress))
                     # item_widget.set_icon(file_path)
@@ -545,20 +856,48 @@ class MainWindow(QMainWindow, Ui_MainWindow):
                     if file_operation == "Deleting":
                         item_widget.set_label_1(f"Deleted from {parent_dir}")
                         item_widget.set_label_2(f"")
+                        # Store timestamp and display for deleted files
+                        if "timestamp" in data and data["timestamp"]:
+                            item_widget.set_completion_timestamp(data["timestamp"])
+                            relative_time = format_relative_time(data["timestamp"])
+                            item_widget.set_timestamp(relative_time)
+                        else:
+                            item_widget.set_timestamp("")
 
                     elif file_operation == "Moving":
                         item_widget.set_label_1(f"Trashed from {parent_dir}")
                         item_widget.set_label_2(f"")
+                        # Store timestamp and display for moved files
+                        if "timestamp" in data and data["timestamp"]:
+                            item_widget.set_completion_timestamp(data["timestamp"])
+                            relative_time = format_relative_time(data["timestamp"])
+                            item_widget.set_timestamp(relative_time)
+                        else:
+                            item_widget.set_timestamp("")
 
                     elif transfer_complete and file_operation == "Uploading":
                         shortened_path = shorten_path(relative_path_display, 32)
                         item_widget.set_label_1(f"Uploaded from <a href=file:///{absolute_path}>{shortened_path}</a>")
                         item_widget.set_label_2(f"{file_size_human}")
+                        # Store timestamp and display in separate timestamp label
+                        if "timestamp" in data and data["timestamp"]:
+                            item_widget.set_completion_timestamp(data["timestamp"])
+                            relative_time = format_relative_time(data["timestamp"])
+                            item_widget.set_timestamp(relative_time)
+                        else:
+                            item_widget.set_timestamp("")
 
                     elif transfer_complete and file_operation == "Downloading":
                         shortened_path = shorten_path(relative_path_display, 32)
                         item_widget.set_label_1(f"Downloaded from <a href=file:///{absolute_path}>{shortened_path}</a>")
                         item_widget.set_label_2(f"{file_size_human}")
+                        # Store timestamp and display in separate timestamp label
+                        if "timestamp" in data and data["timestamp"]:
+                            item_widget.set_completion_timestamp(data["timestamp"])
+                            relative_time = format_relative_time(data["timestamp"])
+                            item_widget.set_timestamp(relative_time)
+                        else:
+                            item_widget.set_timestamp("")
 
                     elif file_operation == "Downloading":
                         # Estimate final size of file before download completes
@@ -571,11 +910,11 @@ class MainWindow(QMainWindow, Ui_MainWindow):
 
                     self.profile_status_pages[profile].listWidget.setItemWidget(item, item_widget)
                     new_list_item = False
-                    logging.info(f"List item updated for file {item_file_name}")
+                    logging.debug(f"List item updated for file {item_file_name}")
                     break
 
         if new_list_item:
-            logging.info(f"Adding new list item for file {file_name}")
+            logging.debug(f"Adding new list item for file {file_name}")
             myQCustomQWidget = TaskList()
             myQCustomQWidget.set_file_name(file_name)
             myQCustomQWidget.set_progress(int(progress))
@@ -585,20 +924,48 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             if file_operation == "Deleting":
                 myQCustomQWidget.set_label_1(f"Deleted from {parent_dir}")
                 myQCustomQWidget.set_label_2(f"")
+                # Store timestamp and display for deleted files
+                if "timestamp" in data and data["timestamp"]:
+                    myQCustomQWidget.set_completion_timestamp(data["timestamp"])
+                    relative_time = format_relative_time(data["timestamp"])
+                    myQCustomQWidget.set_timestamp(relative_time)
+                else:
+                    myQCustomQWidget.set_timestamp("")
 
             elif file_operation == "Moving":
                 myQCustomQWidget.set_label_1(f"Trashed from {parent_dir}")
                 myQCustomQWidget.set_label_2(f"")
+                # Store timestamp and display for moved files
+                if "timestamp" in data and data["timestamp"]:
+                    myQCustomQWidget.set_completion_timestamp(data["timestamp"])
+                    relative_time = format_relative_time(data["timestamp"])
+                    myQCustomQWidget.set_timestamp(relative_time)
+                else:
+                    myQCustomQWidget.set_timestamp("")
 
             elif transfer_complete and file_operation == "Uploading":
                 shortened_path = shorten_path(relative_path_display, 32)
                 myQCustomQWidget.set_label_1(f"Uploaded from <a href=file:///{absolute_path}>{shortened_path}</a>")
                 myQCustomQWidget.set_label_2(f"{file_size_human}")
+                # Store timestamp and display in separate timestamp label
+                if "timestamp" in data and data["timestamp"]:
+                    myQCustomQWidget.set_completion_timestamp(data["timestamp"])
+                    relative_time = format_relative_time(data["timestamp"])
+                    myQCustomQWidget.set_timestamp(relative_time)
+                else:
+                    myQCustomQWidget.set_timestamp("")
 
             elif transfer_complete and file_operation == "Downloading":
                 shortened_path = shorten_path(relative_path_display, 32)
                 myQCustomQWidget.set_label_1(f"Downloaded from <a href=file:///{absolute_path}>{shortened_path}</a>")
                 myQCustomQWidget.set_label_2(f"{file_size_human}")
+                # Store timestamp and display in separate timestamp label
+                if "timestamp" in data and data["timestamp"]:
+                    myQCustomQWidget.set_completion_timestamp(data["timestamp"])
+                    relative_time = format_relative_time(data["timestamp"])
+                    myQCustomQWidget.set_timestamp(relative_time)
+                else:
+                    myQCustomQWidget.set_timestamp("")
 
             elif file_operation == "Downloading":
                 # Estimate final size of file before download completes
@@ -630,10 +997,58 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             if listWidget.count() > 10_000:
                 listWidget.takeItem(listWidget.count() - 1)
 
+    def on_list_scrolled(self, value):
+        """
+        Debounced scroll handler - triggers timestamp update after scrolling stops.
+        Called when scrollbar position changes (user scroll or automatic scroll from new items).
+        """
+        # Restart the debounce timer - only triggers after 200ms of no scrolling
+        self.scroll_update_timer.start()
+
+    def update_relative_times(self):
+        """
+        Update relative time display only for visible items in the viewport.
+        Optimized to update only 10-20 visible items instead of all 10,000 items.
+        Called every 60 seconds by QTimer and when user scrolls the list.
+        """
+        for profile in self.profile_status_pages:
+            listWidget = self.profile_status_pages[profile].listWidget
+
+            # Get the visible viewport area
+            rect = listWidget.viewport().contentsRect()
+            top_index = listWidget.indexAt(rect.topLeft())
+
+            # Skip if no items are visible
+            if not top_index.isValid():
+                continue
+
+            # Get the bottom visible index
+            bottom_index = listWidget.indexAt(rect.bottomLeft())
+
+            # Handle case where bottom index is invalid (last item is visible)
+            if not bottom_index.isValid():
+                bottom_row = listWidget.count() - 1
+            else:
+                bottom_row = bottom_index.row()
+
+            # Only iterate through visible rows (typically 10-20 items instead of 10,000)
+            for row in range(top_index.row(), bottom_row + 1):
+                item = listWidget.item(row)
+                if item is not None:
+                    item_widget = listWidget.itemWidget(item)
+                    if item_widget is not None:
+                        # Get the completion timestamp
+                        timestamp = item_widget.get_completion_timestamp()
+
+                        # If item has a timestamp, update the relative time in the timestamp label
+                        if timestamp is not None:
+                            relative_time = format_relative_time(timestamp)
+                            item_widget.set_timestamp(relative_time)
+
     def show_login(self, profile):
         # Show login window with QT WebEngine
         self.window1 = QWidget()
-        self.window1.setWindowIcon(QIcon(DIR_PATH + "/resources/images/icons8-clouds-80-dark-edge.png"))
+        self.window1.setWindowIcon(QIcon(DIR_PATH + "/resources/images/icons8-cloud-80.png"))
         self.lw = Ui_LoginWindow()
         self.lw.setupUi(self.window1)
         self.window1.show()
@@ -657,7 +1072,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
     def show_external_login(self, profile):
         # Show external login window
         self.window2 = QWidget()
-        self.window2.setWindowIcon(QIcon(DIR_PATH + "/resources/images/icons8-clouds-80-dark-edge.png"))
+        self.window2.setWindowIcon(QIcon(DIR_PATH + "/resources/images/icons8-cloud-80.png"))
         self.lw2 = Ui_ExternalLoginWindow()
         self.lw2.setupUi(self.window2)
         self.window2.show()
@@ -676,10 +1091,10 @@ class MainWindow(QMainWindow, Ui_MainWindow):
     def enable_login_button(self):
         # Enable 'Save' button only when valid URL with login response code is provided.
         if "nativeclient?code=" in self.lw2.lineEdit_response_url.text():
-            logging.debug(f"[GUI] Valid login response code provided. Enabling Save button.")
+            logging.info(f"[GUI] Valid login response code provided. Enabling Save button.")
             self.lw2.pushButton_login.setEnabled(True)
         else:
-            logging.debug(f"[GUI] Invalid login response code provided. Disabling Save button.")
+            logging.info(f"[GUI] Invalid login response code provided. Disabling Save button.")
             self.lw2.pushButton_login.setEnabled(False)
 
     def get_response_url(self, response_url, profile):
@@ -792,7 +1207,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
         index = self.comboBox.findText(old_name)
         if index >= 0:
             self.comboBox.setItemText(index, new_name)
-            logging.debug(f"[MAIN_WINDOW] Updated comboBox item at index {index} from '{old_name}' to '{new_name}'.")
+            logging.info(f"[MAIN_WINDOW] Updated comboBox item at index {index} from '{old_name}' to '{new_name}'.")
         else:
             logging.warning(f"[MAIN_WINDOW] Profile '{old_name}' not found in comboBox.")
 
@@ -801,7 +1216,7 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             self.profile_status_pages[new_name] = self.profile_status_pages.pop(old_name)
             # Also update the profile_name attribute within the ProfileStatusPage instance
             self.profile_status_pages[new_name].profile_name = new_name
-            logging.debug(f"[MAIN_WINDOW] Updated profile_status_pages key from '{old_name}' to '{new_name}'.")
+            logging.info(f"[MAIN_WINDOW] Updated profile_status_pages key from '{old_name}' to '{new_name}'.")
         else:
             logging.warning(f"[MAIN_WINDOW] Profile '{old_name}' not found in profile_status_pages.")
 
@@ -810,9 +1225,9 @@ class MainWindow(QMainWindow, Ui_MainWindow):
             workers[new_name] = workers.pop(old_name)
             # Also update the profile_name attribute within the WorkerThread instance
             workers[new_name].profile_name = new_name
-            logging.debug(f"[MAIN_WINDOW] Updated workers key from '{old_name}' to '{new_name}'.")
+            logging.info(f"[MAIN_WINDOW] Updated workers key from '{old_name}' to '{new_name}'.")
         else:
-            logging.debug(f"[MAIN_WINDOW] No worker found for profile '{old_name}'.")
+            logging.info(f"[MAIN_WINDOW] No worker found for profile '{old_name}'.")
 
         # Force update the UI
         self.comboBox.update()
